#' @name CamposEx2.3.6.3
#' @title Dados Fictícios para Distribuicão de Poisson.
#' @description Verificar se os dados seguem uma distribuicão de
#'     Poisson.
#' @format Um \code{data.frame} com 6 observações e 2 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{Xi}}{ Valor de uma variável genérica. }
#'
#' \item{\code{fi}}{ Frequência de Xi. }
#'
#' }
#' @keywords NP
#' @source CAMPOS (1983), Exemplo 3, seção 2.3.6, pág. 51.
#' @examples
#'
#' data(CamposEx2.3.6.3)
#' # Tamanho da amostra
#' n <- sum(CamposEx2.3.6.3$fi)
#' # Função de distribuição acumulada considerando Poisson(1.2)
#' FXi <- cumsum(dpois(CamposEx2.3.6.3$Xi, lambda = 1.2))
#' # Função empírica de distribuição
#' SXi <- cumsum(CamposEx2.3.6.3$fi)/n
#' # Distâncias (absolutas) entre FXi e SXi
#' FXi_SXi <- abs(FXi - SXi)
#' # Tabela completa
#' cbind(CamposEx2.3.6.3, FXi, SXi, FXi_SXi)
#' # Calcula D
#' D <- max(FXi_SXi)
#' # Não existe forma fechada para calcular o p-valor, por isso o D deve
#' # ser comparado com valores tabelados
#'
NULL
